@@ -306,9 +306,8 @@ impl HashSearchWorker {
             .name("scatter_padding_and_find_match")
             .program(
                 &Program::builder()
-                    .binaries(&[
-                        &include_bytes!(concat!(env!("OUT_DIR"), "/sha1_prefix_matcher"))[..],
-                    ])
+                    .src(include_str!("sha1_prefix_matcher.cl"))
+                    .cmplr_opt("-Werror")
                     .build(&context)?,
             )
             .arg(
@@ -349,7 +348,7 @@ impl HashSearchWorker {
                     )
                     .build()?,
             )
-            .arg(partially_hashed_commit.dynamic_blocks.len())
+            .arg(partially_hashed_commit.dynamic_blocks.len() as u64)
             .arg(&successful_match_receiver)
             .queue(queue)
             .global_work_size(num_threads)
